@@ -1115,6 +1115,7 @@ afs_linux_dentry_revalidate(struct dentry *dp, int flags)
     struct dentry *parent;
     int valid;
     struct afs_fakestat_state fakestate;
+    int force_drop = 0;
 
 #ifdef LOOKUP_RCU
     /* We don't support RCU path walking */
@@ -1182,11 +1183,15 @@ afs_linux_dentry_revalidate(struct dentry *dp, int flags)
 	 */
 
 	if (hgetlo(pvcp->f.m.DataVersion) > dp->d_time || !(vcp->f.states & CStatd)) {
+	    int code;
 
 	    credp = crref();
-	    afs_lookup(pvcp, (char *)dp->d_name.name, &tvc, credp);
+	    code = afs_lookup(pvcp, (char *)dp->d_name.name, &tvc, credp);
 	    if (!tvc || tvc != vcp) {
 		dput(parent);
+		/* Force unhash if name is known not to exist. */
+		if (code == ENOENT)
+		    force_drop = 1;
 		goto bad_dentry;
 	    }
 
@@ -1235,9 +1240,18 @@ afs_linux_dentry_revalidate(struct dentry *dp, int flags)
 	crfree(credp);
 
     if (!valid) {
-	shrink_dcache_parent(dp);
-	d_drop(dp);
+	/*
+	 * If we had a negative lookup for the name we want to forcibly
+	 * unhash the dentry.
+	 * Otherwise use d_invalidate which will not unhash it if still in use.
+	 */
+	if (force_drop) {
+	    shrink_dcache_parent(dp);
+	    d_drop(dp);
+	} else
+	    d_invalidate(dp);
     }
+
     return valid;
 
   bad_dentry:
