@@ -152,7 +152,8 @@ struct brequest {
     afs_ucred_t *cred;	/* credentials to use for operation */
     afs_size_t size_parm[BPARMS];	/* random parameters */
     void *ptr_parm[BPARMS];	/* pointer parameters */
-    afs_int32 code;		/* return code */
+    afs_int32 code_raw;		/* return code from AFS routines */
+    afs_int32 code_checkcode;	/* the afs_CheckCode-translated code */
     short refCount;		/* use counter for this structure */
     char opcode;		/* what to do (store, fetch, etc) */
     char flags;			/* free, etc */
@@ -894,6 +895,7 @@ struct vcache {
 #ifdef AFS_SUN5_ENV
     struct afs_q multiPage;	/* list of multiPage_range structs */
 #endif
+    afs_uint32 lastBRLWarnTime; /* last time we warned about byte-range locks */
 };
 
 #define	DONT_CHECK_MODE_BITS	0
