@@ -1387,7 +1387,13 @@ afs_shutdown(void)
     if (afs_shuttingdown)
 	return;
 
+    /* Give up all of our callbacks if we can. This must be done before setting
+     * afs_shuttingdown, since it calls afs_InitReq, which will fail if
+     * afs_shuttingdown is set. */
+    afs_FlushVCBs(2);
+
     afs_shuttingdown = 1;
+
     if (afs_cold_shutdown)
 	afs_warn("afs: COLD ");
     else
