@@ -27,6 +27,8 @@
 #define	AFS_SUN55_ENV		1
 #define	AFS_SUN56_ENV		1
 #define AFS_SUN57_ENV		1
+#define AFS_SUN58_ENV		1
+#define AFS_SUN59_ENV		1
 #define AFS_BOZONLOCK_ENV       1
 
 #define AFS_X86_ENV		1
@@ -36,27 +38,32 @@
 
 #define AFS_HAVE_FLOCK_SYSID    1
 
-
 #include <afs/afs_sysnames.h>
 
 #define AFS_GLOBAL_SUNLOCK	1	/* For global locking */
 #define RXK_LISTENER_ENV   1
 #define AFS_GCPAGS		1	/* if nonzero, garbage collect PAGs */
 
+#ifdef AFS_NAMEI_ENV
+#define AFS_64BIT_IOPS_ENV	1	/* needed for NAMEI... */
+#else /* AFS_NAMEI_ENV */
 #define	AFS_3DISPARES		1	/* Utilize the 3 available disk inode 'spares' */
-#define	AFS_SYSCALL		73
+#endif /* AFS_NAMEI_ENV */
+
+#define	AFS_SYSCALL		65
 
 /* File system entry (used if mount.h doesn't define MOUNT_AFS */
 #define AFS_MOUNT_AFS	 "afs"
 
 /* Machine / Operating system information */
-#define sys_sunx86_57	1
-#define SYS_NAME	"sunx86_57"
-#define SYS_NAME_ID	SYS_NAME_ID_sunx86_57
+#define sys_sunx86_59	1
+#define SYS_NAME	"sunx86_59"
+#define SYS_NAME_ID	SYS_NAME_ID_sunx86_59
 #define AFSLITTLE_ENDIAN	1
 #define AFS_HAVE_FFS    1	/* Use system's ffs. */
 #define AFS_HAVE_VXFS	1	/* Support cache on Veritas vxfs file system */
 #define AFS_HAVE_STATVFS 1	/* System supports statvfs */
+#define AFS_HAVE_STATVFS64	1	/* System supports statvfs64 */
 #define AFS_VM_RDWR_ENV	1	/* read/write implemented via VM */
 #define AFS_USE_GETTIMEOFDAY 1	/* use gettimeofday to implement rx clock */
 
@@ -129,6 +136,9 @@
 #define AFS_ENV			1
 #define AFS_USR_SUN5_ENV	1
 #define AFS_USR_SUN6_ENV	1
+#define AFS_USR_SUN7_ENV        1
+#define AFS_USR_SUN8_ENV        1
+#define AFS_USR_SUN9_ENV        1
 
 #include <afs/afs_sysnames.h>
 
@@ -137,18 +147,19 @@
 #endif
 
 #define	AFS_3DISPARES		1	/* Utilize the 3 available disk inode 'spares' */
-#define	AFS_SYSCALL		73
+#define	AFS_SYSCALL		65
 
 /* File system entry (used if mount.h doesn't define MOUNT_AFS */
 #define AFS_MOUNT_AFS	 1
 
 /* Machine / Operating system information */
-#define sys_sunx86_57	1
-#define SYS_NAME	"sunx86_57"
-#define SYS_NAME_ID	SYS_NAME_ID_sunx86_57
+#define sys_sunx86_59	1
+#define SYS_NAME	"sunx86_59"
+#define SYS_NAME_ID	SYS_NAME_ID_sunx86_59
 #define AFSLITTLE_ENDIAN	1
 #define AFS_HAVE_FFS            1	/* Use system's ffs. */
 #define AFS_HAVE_STATVFS      1	/* System supports statvfs */
+#define AFS_HAVE_STATVFS64	1	/* System supports statvfs64 */
 
 /* Extra kernel definitions (from kdefs file) */
 #ifdef KERNEL
